# Data Format Conversion Tools

Introduction to the `earthstat.data_converter` module, which provides efficient solutions for converting between different geospatial data formats, catering to a variety of analysis needs.

## File Format Conversions

### Converting NetCDF to GeoTIFF Format
:::earthstat.data_converter.netcdf_to_tiff

### Transforming HDF5 to GeoTIFF Format
:::earthstat.data_converter.hdf5_to_tiff
